@@ -110,7 +110,7 @@ def _has_single_output_row(scope):
     return isinstance(scope.expression, exp.Select) and (
         all(isinstance(e.unalias(), exp.AggFunc) for e in scope.expression.selects)
         or _is_limit_1(scope)
-        or not scope.expression.args.get("from")
+        or not scope.expression.args.get("from_")
     )
 
 
