@@ -1,7 +1,6 @@
 use crate::settings::TokenType;
 use crate::trie::{Trie, TrieResult};
 use crate::{Token, TokenTypeSettings, TokenizerDialectSettings, TokenizerSettings};
-use pyo3::exceptions::PyException;
 use pyo3::prelude::*;
 use std::cmp::{max, min};
 
@@ -45,7 +44,7 @@ impl Tokenizer {
         &self,
         sql: &str,
         dialect_settings: &TokenizerDialectSettings,
-    ) -> Result<Vec<Token>, PyErr> {
+    ) -> (Vec<Token>, Option<String>) {
         let mut state = TokenizerState::new(
             sql,
             &self.settings,
@@ -53,9 +52,14 @@ impl Tokenizer {
             dialect_settings,
             &self.keyword_trie,
         );
-        state.tokenize().map_err(|e| {
-            PyException::new_err(format!("Error tokenizing '{}': {}", e.context, e.message))
-        })
+        let tokenize_result = state.tokenize();
+        match tokenize_result {
+            Ok(tokens) => (tokens, None),
+            Err(e) => {
+                let msg = format!("Error tokenizing '{}': {}", e.context, e.message);
+                (state.tokens, Some(msg))
+            }
+        }
     }
 }
 
@@ -173,7 +177,7 @@ impl<'a> TokenizerState<'a> {
         if Some(&self.token_types.break_) == self.settings.white_space.get(&self.current_char) {
             // Ensures we don't count an extra line if we get a \r\n line break sequence.
             if !(self.current_char == '\r' && self.peek_char == '\n') {
-                self.column = 1;
+                self.column = i as usize;
                 self.line += 1;
             }
         } else {
@@ -440,13 +444,13 @@ impl<'a> TokenizerState<'a> {
 
                 if !tag.is_empty()
                     && self.settings.heredoc_tag_is_identifier
-                    && (self.is_end || !self.is_identifier(&tag))
+                    && (self.is_end || tag.chars().all(|c| c.is_ascii_digit()) || tag.chars().any(|c| c.is_whitespace()))
                 {
                     if !self.is_end {
                         self.advance(-1)?;
                     }
 
-                    self.advance(-(tag.len() as isize))?;
+                    self.advance(-(tag.chars().count() as isize))?;
                     self.add(self.token_types.heredoc_string_alternative, None)?;
                     return Ok(true);
                 }
@@ -464,7 +468,7 @@ impl<'a> TokenizerState<'a> {
             self.extract_string(&end, false, token_type == self.token_types.raw_string, true)?;
 
         if let Some(b) = base {
-            if u128::from_str_radix(&text, b).is_err() {
+            if !text.is_empty() && u128::from_str_radix(&text, b).is_err() {
                 return self.error_result(format!(
                     "Numeric string contains invalid characters from {}:{}",
                     self.line, self.start
@@ -683,9 +687,10 @@ impl<'a> TokenizerState<'a> {
                     continue;
                 }
             }
-            if self.chars(delimiter.len()) == delimiter {
-                if delimiter.len() > 1 {
-                    self.advance((delimiter.len() - 1) as isize)?;
+            let delimiter_char_count = delimiter.chars().count();
+            if self.chars(delimiter_char_count) == delimiter {
+                if delimiter_char_count > 1 {
+                    self.advance((delimiter_char_count - 1) as isize)?;
                 }
                 break;
             }
@@ -716,16 +721,6 @@ impl<'a> TokenizerState<'a> {
         name.is_alphabetic() || name == '_'
     }
 
-    fn is_identifier(&self, s: &str) -> bool {
-        s.chars().enumerate().all(|(i, c)| {
-            if i == 0 {
-                self.is_alphabetic_or_underscore(c)
-            } else {
-                self.is_alphabetic_or_underscore(c) || c.is_ascii_digit()
-            }
-        })
-    }
-
     fn is_numeric(&self, s: &str) -> bool {
         s.chars().all(|c| c.is_ascii_digit())
     }
