@@ -58,6 +58,15 @@ BINARY;
 FROM_BASE64(tbl.str_col);
 BINARY;
 
+ANY_VALUE(tbl.bool_col);
+BOOLEAN;
+
+ANY_VALUE(tbl.bigint_col);
+BIGINT;
+
+ANY_VALUE(tbl.date_col);
+DATE;
+
 ANY_VALUE(tbl.str_col);
 STRING;
 
@@ -1535,6 +1544,14 @@ STRING;
 STRUCT(tbl.str_col);
 STRUCT<str_col STRING>;
 
+# dialect: bigquery
+LENGTH(tbl.str_col);
+BIGINT;
+
+# dialect: bigquery
+LENGTH(tbl.bin_col);
+BIGINT;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
@@ -1639,6 +1656,22 @@ VARCHAR;
 BIT_LENGTH('abc');
 INT;
 
+# dialect: snowflake
+BITMAP_BIT_POSITION(tbl.int_col);
+BIGINT;
+
+# dialect: snowflake
+BITMAP_BUCKET_NUMBER(tbl.int_col);
+BIGINT;
+
+# dialect: snowflake
+BITMAP_CONSTRUCT_AGG(tbl.int_col);
+BINARY;
+
+# dialect: snowflake
+BITMAP_COUNT(BITMAP_CONSTRUCT_AGG(tbl.int_col));
+BIGINT;
+
 # dialect: snowflake
 BIT_LENGTH(tbl.str_col);
 INT;
@@ -1647,6 +1680,118 @@ INT;
 BIT_LENGTH(tbl.bin_col);
 INT;
 
+# dialect: snowflake
+BITNOT(5);
+INT;
+
+# dialect: snowflake
+BITNOT(tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+BIT_NOT(5);
+INT;
+
+# dialect: snowflake
+BITAND(2, 4);
+INT;
+
+# dialect: snowflake
+BITAND(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+BIT_AND(2, 4);
+INT;
+
+# dialect: snowflake
+BITOR(2, 4);
+INT;
+
+# dialect: snowflake
+BITOR(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+BITSHIFTLEFT(2, 1);
+INT;
+
+# dialect: snowflake
+BITSHIFTLEFT(tbl.bin_col, 4);
+BINARY;
+
+# dialect: snowflake
+BITSHIFTRIGHT(24, 1);
+INT;
+
+# dialect: snowflake
+BITSHIFTRIGHT(tbl.bin_col, 4);
+BINARY;
+
+# dialect: snowflake
+BITXOR(5, 3);
+INT;
+
+# dialect: snowflake
+BITXOR(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+BITANDAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITAND_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_AND_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_ANDAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITORAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITOR_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_OR_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_ORAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITXORAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITXOR_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_XOR_AGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BIT_XORAGG(tbl.int_col);
+NUMBER(38, 0);
+
+# dialect: snowflake
+BITMAP_OR_AGG(tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+BOOLXOR_AGG(tbl.bool_col);
+BOOLEAN;
+
 # dialect: snowflake
 BOOLNOT(tbl.int_col);
 BOOLEAN;
@@ -1655,10 +1800,46 @@ BOOLEAN;
 BOOLNOT(NULL);
 BOOLEAN;
 
+# dialect: snowflake
+BOOLAND(1, -2);
+BOOLEAN;
+
+# dialect: snowflake
+BOOLOR(1, 0);
+BOOLEAN;
+
 # dialect: snowflake
 BOOLXOR(2, 0);
 BOOLEAN;
 
+# dialect: snowflake
+BOOLAND_AGG(tbl.bool_col);
+BOOLEAN;
+
+# dialect: snowflake
+BOOLOR_AGG(tbl.bool_col);
+BOOLEAN;
+
+# dialect: snowflake
+ARRAY_AGG(tbl.bin_col);
+ARRAY<BINARY>;
+
+# dialect: snowflake
+ARRAY_AGG(tbl.bool_col);
+ARRAY<BOOLEAN>;
+
+# dialect: snowflake
+ARRAY_AGG(tbl.date_col);
+ARRAY<DATE>;
+
+# dialect: snowflake
+ARRAY_AGG(tbl.double_col);
+ARRAY<DOUBLE>;
+
+# dialect: snowflake
+ARRAY_AGG(tbl.str_col);
+ARRAY<VARCHAR>;
+
 # dialect: snowflake
 CHARINDEX('world', 'hello world');
 INT;
@@ -1667,6 +1848,18 @@ INT;
 CHARINDEX('world', 'hello world', 1);
 INT;
 
+# dialect: snowflake
+CASE WHEN score >= 90 THEN 100 WHEN score >= 80 THEN 220 END;
+INT;
+
+# dialect: snowflake
+CASE WHEN score >= 90 THEN 'A' WHEN score >= 80 THEN 'B' ELSE 'C' END;
+VARCHAR;
+
+# dialect: snowflake
+CASE WHEN score >= 90 THEN TRUE WHEN score >= 80 THEN FALSE ELSE NULL END;
+BOOLEAN;
+
 # dialect: snowflake
 CEIL(3.14);
 DOUBLE;
@@ -1699,6 +1892,30 @@ VARCHAR;
 COSH(1.5);
 DOUBLE;
 
+# dialect: snowflake
+COALESCE(42, 0, 100);
+INT;
+
+# dialect: snowflake
+COALESCE(1.5, 2.7);
+DOUBLE;
+
+# dialect: snowflake
+COALESCE(1::BIGINT, 2::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+COALESCE('hello', 'world');
+VARCHAR;
+
+# dialect: snowflake
+COALESCE(CAST('2024-01-01' AS DATE), CAST('2024-12-31' AS DATE));
+DATE;
+
+# dialect: snowflake
+COALESCE(TRUE, FALSE);
+BOOLEAN;
+
 # dialect: snowflake
 COMPRESS('Hello World', 'SNAPPY');
 BINARY;
@@ -1887,6 +2104,50 @@ TIME;
 DATE_TRUNC('minute', TO_TIMESTAMP('2024-05-09 08:50:57.891'));
 TIMESTAMP;
 
+# dialect: snowflake
+TIMESTAMP_FROM_PARTS(2024, 5, 9, 14, 30, 45);
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMP_FROM_PARTS(2024, 5, 9, 14, 30, 45, 123);
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMP_FROM_PARTS(CAST('2024-05-09' AS DATE), CAST('14:30:45' AS TIME));
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMPFROMPARTS(2024, 5, 9, 14, 30, 45);
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMPFROMPARTS(CAST('2024-05-09' AS DATE), CAST('14:30:45' AS TIME));
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMP_LTZ_FROM_PARTS(2024, 5, 9, 14, 30, 45);
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TIMESTAMP_LTZ_FROM_PARTS(2024, 5, 9, 14, 30, 45, 123);
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TIMESTAMP_NTZ_FROM_PARTS(2024, 5, 9, 14, 30, 45);
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMP_NTZ_FROM_PARTS(2024, 5, 9, 14, 30, 45, 123);
+TIMESTAMP;
+
+# dialect: snowflake
+TIMESTAMP_TZ_FROM_PARTS(2024, 5, 9, 14, 30, 45, 123, 'UTC');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+TIMESTAMP_TZ_FROM_PARTS(2024, 5, 9, 14, 30, 45, 123);
+TIMESTAMPTZ;
+
 # dialect: snowflake
 EDITDISTANCE('hello', 'world');
 INT;
@@ -1899,6 +2160,10 @@ INT;
 EDITDISTANCE('hello', 'world', 3);
 INT;
 
+# dialect: snowflake
+EQUAL_NULL(1, 2);
+BOOLEAN;
+
 # dialect: snowflake
 EXTRACT(YEAR, CAST('2024-05-09' AS DATE));
 INT;
@@ -1911,6 +2176,110 @@ INT;
 EXTRACT(MINUTE, CAST('08:50:57' AS TIME));
 INT;
 
+# dialect: snowflake
+YEAR(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+YEAR(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+YEAROFWEEK(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+YEAROFWEEK(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+YEAROFWEEKISO(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+YEAROFWEEKISO(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+DAY(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+DAY(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+DAYOFMONTH(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+DAYOFMONTH(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+DAYOFWEEK(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+DAYOFWEEK(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+DAYOFWEEKISO(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+DAYOFWEEKISO(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+DAYOFYEAR(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+DAYOFYEAR(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+WEEK(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+WEEK(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+WEEKOFYEAR(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+WEEKOFYEAR(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+WEEKISO(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+WEEKISO(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+MONTH(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+MONTH(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
+# dialect: snowflake
+QUARTER(CAST('2024-05-09' AS DATE));
+TINYINT;
+
+# dialect: snowflake
+QUARTER(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+TINYINT;
+
 # dialect: snowflake
 EXP(1);
 DOUBLE;
@@ -1935,6 +2304,46 @@ DOUBLE;
 FLOOR(tbl.bigint_col, -1);
 BIGINT;
 
+# dialect: snowflake
+GETBIT(11, 3);
+INT;
+
+# dialect: snowflake
+GROUPING(tbl.str_col);
+INT;
+
+# dialect: snowflake
+GROUPING(tbl.bigint_col);
+INT;
+
+# dialect: snowflake
+GROUPING_ID(tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+GROUPING_ID(tbl.bigint_col, tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+GREATEST(tbl.bigint_col, tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+GREATEST(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+GREATEST(tbl.str_col, tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+GREATEST(tbl.double_col, tbl.bigint_col);
+DOUBLE;
+
+# dialect: snowflake
+GREATEST(tbl.bigint_col, tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 ENDSWITH('hello world', 'world');
 BOOLEAN;
@@ -1951,6 +2360,38 @@ BOOLEAN;
 ENDSWITH(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+GREATEST_IGNORE_NULLS(1, 2, 3);
+INT;
+
+# dialect: snowflake
+GREATEST_IGNORE_NULLS(1, 2.5, 3);
+DOUBLE;
+
+# dialect: snowflake
+GREATEST_IGNORE_NULLS('a', 'b', 'c');
+VARCHAR;
+
+# dialect: snowflake
+GREATEST_IGNORE_NULLS(CAST('2023-01-01' AS DATE), CAST('2023-01-02' AS DATE));
+DATE;
+
+# dialect: snowflake
+LEAST_IGNORE_NULLS(1, 2, 3);
+INT;
+
+# dialect: snowflake
+LEAST_IGNORE_NULLS(1, 2.5, 3);
+DOUBLE;
+
+# dialect: snowflake
+LEAST_IGNORE_NULLS('a', 'b', 'c');
+VARCHAR;
+
+# dialect: snowflake
+LEAST_IGNORE_NULLS(CAST('2023-01-01' AS DATE), CAST('2023-01-02' AS DATE));
+DATE;
+
 # dialect: snowflake
 HEX_DECODE_BINARY('48656C6C6F');
 BINARY;
@@ -1987,6 +2428,62 @@ VARCHAR;
 INITCAP(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+IFF(TRUE, 42, 0);
+INT;
+
+# dialect: snowflake
+IFF(TRUE, 42, NULL);
+INT;
+
+# dialect: snowflake
+IFF(col1 > 0, 'yes', 'no');
+VARCHAR;
+
+# dialect: snowflake
+IFF(FALSE, 1.5, 2.7);
+DOUBLE;
+
+# dialect: snowflake
+IFF(TRUE, CAST('2024-01-01' AS DATE), CAST('2024-12-31' AS DATE));
+DATE;
+
+# dialect: snowflake
+IFNULL('hello', 'world');
+VARCHAR;
+
+# dialect: snowflake
+IFNULL(1, 2);
+INT;
+
+# dialect: snowflake
+IFNULL(1.5, 2.7);
+DOUBLE;
+
+# dialect: snowflake
+IFNULL(5::BIGINT, 10::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+IFNULL(CAST('2024-01-01' AS DATE), CAST('2024-12-31' AS DATE));
+DATE;
+
+# dialect: snowflake
+IFNULL(5::BIGINT, 2.71::FLOAT);
+FLOAT;
+
+# dialect: snowflake
+IS_NULL_VALUE(payload:field);
+BOOLEAN;
+
+# dialect: snowflake
+1 IN (1, 2, 3);
+BOOLEAN;
+
+# dialect: snowflake
+1 NOT IN (1, 2, 3);
+BOOLEAN;
+
 # dialect: snowflake
 JAROWINKLER_SIMILARITY('hello', 'world');
 INT;
@@ -2083,6 +2580,22 @@ DATE;
 PREVIOUS_DAY(CAST('2024-05-09 08:50:57' AS TIMESTAMP), 'MONDAY');
 DATE;
 
+# dialect: snowflake
+DECODE(x, 1, 100, 2, 200, 0);
+INT;
+
+# dialect: snowflake
+DECODE(status, 'A', 'Active', 'I', 'Inactive', 'Neither');
+VARCHAR;
+
+# dialect: snowflake
+DECODE(100, 100, 1, 90, 2, 5.5);
+DOUBLE;
+
+# dialect: snowflake
+DECODE(x, 1, 100, NULL);
+INT;
+
 # dialect: snowflake
 PI();
 DOUBLE;
@@ -2139,6 +2652,70 @@ VARCHAR;
 MONTHNAME(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
 VARCHAR;
 
+# dialect: snowflake
+NVL2(col1, col2, col3);
+UNKNOWN;
+
+# dialect: snowflake
+NVL('hello', 'world');
+VARCHAR;
+
+# dialect: snowflake
+NVL(tbl.int_col, 42);
+INT;
+
+# dialect: snowflake
+NVL(tbl.date_col, CAST('2024-01-01' AS DATE));
+DATE;
+
+# dialect: snowflake
+NVL(1, 3.14);
+DOUBLE;
+
+# dialect: snowflake
+NVL(5::BIGINT, 2.71::FLOAT);
+FLOAT;
+
+# dialect: snowflake
+NULLIF(1, 2);
+INT;
+
+# dialect: snowflake
+NULLIF(1.5, 2.7);
+DOUBLE;
+
+# dialect: snowflake
+NULLIF(5::BIGINT, 10::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+NULLIF(CAST('2024-01-01' AS DATE), CAST('2024-12-31' AS DATE));
+DATE;
+
+# dialect: snowflake
+NULLIF(1::INT, 2::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+NULLIF(1::INT, 2.5::DOUBLE);
+DOUBLE;
+
+# dialect: snowflake
+NULLIFZERO(5);
+INT;
+
+# dialect: snowflake
+NULLIFZERO(5::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+NULLIFZERO(5.5);
+DOUBLE;
+
+# dialect: snowflake
+NULLIFZERO(5.5::FLOAT);
+FLOAT;
+
 # dialect: snowflake
 MOD(tbl.bigint_col, 3);
 BIGINT;
@@ -2159,6 +2736,22 @@ DOUBLE;
 MONTHS_BETWEEN(tbl.timestamp_col, CAST('2019-02-15 01:00:00' AS TIMESTAMP));
 DOUBLE;
 
+# dialect: snowflake
+REGR_AVGX(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_AVGY(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(1.0, 2.0);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALY(1.0, 2.0);
+DOUBLE;
+
 # dialect: snowflake
 'foo' REGEXP 'bar';
 BOOLEAN;
@@ -2479,6 +3072,10 @@ DOUBLE;
 SIGN(tbl.double_col);
 INT;
 
+# dialect: snowflake
+SKEW(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 SOUNDEX(tbl.str_col);
 VARCHAR;
@@ -2655,6 +3252,26 @@ INT;
 WIDTH_BUCKET(tbl.double_col, 0, 100, 10);
 INT;
 
+# dialect: snowflake
+ZEROIFNULL(5);
+INT;
+
+# dialect: snowflake
+ZEROIFNULL(5::BIGINT);
+BIGINT;
+
+# dialect: snowflake
+ZEROIFNULL(5.5);
+DOUBLE;
+
+# dialect: snowflake
+ZEROIFNULL(5.5::FLOAT);
+FLOAT;
+
+# dialect: snowflake
+ZEROIFNULL(5.12::DECIMAL(10,2));
+DECIMAL(10, 2);
+
 # dialect: snowflake
 TRIM('hello world');
 VARCHAR;
@@ -2783,10 +3400,114 @@ BOOLEAN;
 ILIKE(tbl.str_col, 'pattern');
 BOOLEAN;
 
+# dialect: snowflake
+OBJECT_AGG(tbl.str_col, tbl.variant_col);
+OBJECT;
+
+# dialect: snowflake
+PERCENTILE_DISC(0.5) WITHIN GROUP (ORDER BY tbl.int_col);
+INT;
+
+# dialect: snowflake
+PERCENTILE_DISC(0.25) WITHIN GROUP (ORDER BY tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 PARSE_IP('192.168.1.1', 'INET');
 OBJECT;
 
+# dialect: snowflake
+MAX_BY('foo', tbl.bigint_col);
+VARCHAR;
+
+# dialect: snowflake
+MAX_BY('foo', tbl.bigint_col, 3);
+ARRAY<VARCHAR>;
+
+# dialect: snowflake
+MIN_BY('foo', tbl.bigint_col);
+VARCHAR;
+
+# dialect: snowflake
+MIN_BY('foo', tbl.bigint_col, 3);
+ARRAY<VARCHAR>;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.bigint_col, 0.5);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.double_col, 0.5);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.int_col, 0.9);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.bigint_col, 0.5) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.double_col, 0.5) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_PERCENTILE(tbl.int_col, 0.9) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+APPROX_TOP_K_ACCUMULATE(tbl.str_col, 10);
+OBJECT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.double_col);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(*);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(DISTINCT tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.str_col) OVER (PARTITION BY 1);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.bigint_col) OVER (PARTITION BY 1);
+BIGINT;
+
+# dialect: snowflake
+APPROX_COUNT_DISTINCT(tbl.double_col) OVER (PARTITION BY 1);
+BIGINT;
+
+# dialect: snowflake
+APPROX_TOP_K(tbl.bigint_col);
+ARRAY;
+
+# dialect: snowflake
+APPROX_TOP_K(tbl.str_col);
+ARRAY;
+
+# dialect: snowflake
+APPROX_TOP_K(tbl.str_col, 5);
+ARRAY;
+
+# dialect: snowflake
+APPROX_TOP_K(tbl.str_col, 5, 1000);
+ARRAY;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
